@@ -120,6 +120,9 @@ NSObject (TestMethods)
     return [first compare:second];
 }
 
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wdeprecated-declarations"
+
 + (id)replacementObjectForArchiver:(NSArchiver*)archiver of:(NSObject*)object
 {
     return [object replacementObjectForArchiver:archiver];
@@ -130,6 +133,8 @@ NSObject (TestMethods)
     return [object replacementObjectForKeyedArchiver:archiver];
 }
 
+#pragma clang diagnostic pop
+
 + (id)replacementObjectForCoder:(NSCoder*)archiver of:(NSObject*)object
 {
     return [object replacementObjectForCoder:archiver];
@@ -661,7 +666,7 @@ NSObject (TestMethods)
     return self;
 }
 
-- (instancetype)copyWithZone:(NSZone*)zone
+- (instancetype)copyWithZone:(NSZone*)__attribute__((__unused__))zone
 {
     return [self retain];
 }
