@@ -4,21 +4,52 @@ Tests for the Key-Value Coding support in OC_PythonObject
 NOTE: Testcases here should be synchronized with the Key-Value Coding tests
 in PyObjCTools.test.test_keyvalue and Foundation.test.test_keyvalue.
 """
-from __future__ import unicode_literals
-import objc
-from PyObjCTools.TestSupport import *
-from PyObjCTest.fnd import *
+import os
+import sys
 
+import objc
+from PyObjCTest.fnd import (
+    NSObject,
+    NSArray,
+    NSKeyValueObservingOptionOld,
+    NSKeyValueObservingOptionNew,
+    NSAutoreleasePool,
+)
+from PyObjCTest.keyvaluehelper import (
+    PyObjCTestObserver,
+    DO_SETVALUE_FORKEYPATH,
+    DO_SETVALUESFORKEYSFROMDICT,
+    DO_SETVALUE_FORKEY,
+    DO_VALUEFORKEY,
+    DO_VALUEFORKEYPATH,
+    DO_STOREDVALUEFORKEY,
+    DO_TAKESTOREDVALUE_FORKEY,
+    DO_TAKEVALUESFROMDICT,
+    DO_TAKEVALUE_FORKEY,
+    DO_TAKEVALUE_FORKEYPATH,
+    DO_VALUESFORKEYS,
+    IndirectString,
+    IndirectNumber,
+    DirectString,
+    DirectNumber,
+    KVPySubOverObjCPath,
+    KVPySubOverObjCBase,
+    KVPySubObjCPath,
+    KVPySubObjCBase,
+    KVPyPath,
+    KVPyBase,
+    PyObjCTest_KVPathClass,
+    PyObjCTest_KVBaseClass,
+)
 
 # Native code is needed to access the python class from Objective-C, otherwise
 # the Key-Value support cannot be tested.
 from PyObjCTest.testbndl import PyObjC_TestClass3 as STUB
 from PyObjCTest.testbndl import PyObjCTest_KeyValueObserver
-from PyObjCTest.testbndl import *
-from PyObjCTest.keyvaluehelper import *
+from PyObjCTools.TestSupport import TestCase, min_os_level
 
 
-class KeyValueClass2(object):
+class KeyValueClass2:
     def __init__(self):
         self.key3 = 3
         self._key4 = "4"
@@ -52,7 +83,7 @@ class KeyValueClass2(object):
         self.key5 = value * 5
 
 
-class KeyValueClass3(object):
+class KeyValueClass3:
     __slots__ = ("foo",)
 
     def __init__(self):
@@ -76,9 +107,8 @@ class PyKeyValueCoding(TestCase):
         # Private instance variables ('anObject.__value') are not accessible using
         # key-value coding.
         o = KeyValueClass2()
-        self.assertRaises(
-            KeyError, STUB.keyValue_forObject_key_, DO_VALUEFORKEY, o, "private"
-        )
+        with self.assertRaisesRegex(KeyError, "private"):
+            STUB.keyValue_forObject_key_(DO_VALUEFORKEY, o, "private")
 
     def testValueForKey(self):
         o = KeyValueClass2()
@@ -95,14 +125,15 @@ class PyKeyValueCoding(TestCase):
             STUB.keyValue_forObject_key_(DO_VALUEFORKEY, o, "pythonConvention"), "GOOD"
         )
 
-        self.assertRaises(
-            KeyError, STUB.keyValue_forObject_key_, DO_VALUEFORKEY, o, "nokey"
-        )
+        with self.assertRaisesRegex(KeyError, "nokey"):
+            STUB.keyValue_forObject_key_(DO_VALUEFORKEY, o, "nokey")
 
     def testValueForKey2(self):
         o = KeyValueClass3()
 
-        self.assertEqual(STUB.keyValue_forObject_key_(DO_VALUEFORKEY, o, "foo"), "foobar")
+        self.assertEqual(
+            STUB.keyValue_forObject_key_(DO_VALUEFORKEY, o, "foo"), "foobar"
+        )
         self.assertEqual(
             STUB.keyValue_forObject_key_(DO_VALUEFORKEY, o, "bar"), "foobarfoobar"
         )
@@ -114,19 +145,25 @@ class PyKeyValueCoding(TestCase):
         o = KeyValueClass2()
         o.addMultiple()
 
-        self.assertEqual(STUB.keyValue_forObject_key_(DO_STOREDVALUEFORKEY, o, "key1"), 1)
-        self.assertEqual(STUB.keyValue_forObject_key_(DO_STOREDVALUEFORKEY, o, "key2"), 2)
-        self.assertEqual(STUB.keyValue_forObject_key_(DO_STOREDVALUEFORKEY, o, "key3"), 3)
+        self.assertEqual(
+            STUB.keyValue_forObject_key_(DO_STOREDVALUEFORKEY, o, "key1"), 1
+        )
+        self.assertEqual(
+            STUB.keyValue_forObject_key_(DO_STOREDVALUEFORKEY, o, "key2"), 2
+        )
+        self.assertEqual(
+            STUB.keyValue_forObject_key_(DO_STOREDVALUEFORKEY, o, "key3"), 3
+        )
         self.assertEqual(
             STUB.keyValue_forObject_key_(DO_STOREDVALUEFORKEY, o, "key4"), "4"
         )
         self.assertEqual(
-            STUB.keyValue_forObject_key_(DO_STOREDVALUEFORKEY, o, "multiple"), o.multiple
+            STUB.keyValue_forObject_key_(DO_STOREDVALUEFORKEY, o, "multiple"),
+            o.multiple,
         )
 
-        self.assertRaises(
-            KeyError, STUB.keyValue_forObject_key_, DO_STOREDVALUEFORKEY, o, "nokey"
-        )
+        with self.assertRaisesRegex(KeyError, "nokey"):
+            STUB.keyValue_forObject_key_(DO_STOREDVALUEFORKEY, o, "nokey")
 
     def testStoredValueForKey2(self):
         o = KeyValueClass3()
@@ -165,13 +202,12 @@ class PyKeyValueCoding(TestCase):
             o.multiple.level2.level3.keyB,
         )
 
-        self.assertRaises(
-            KeyError,
-            STUB.keyValue_forObject_key_,
-            DO_VALUEFORKEYPATH,
-            o,
-            "multiple.level2.nokey",
-        )
+        with self.assertRaisesRegex(KeyError, "nokey"):
+            STUB.keyValue_forObject_key_(
+                DO_VALUEFORKEYPATH,
+                o,
+                "multiple.level2.nokey",
+            )
 
     def testValuesForKeys(self):
         o = KeyValueClass2()
@@ -183,13 +219,12 @@ class PyKeyValueCoding(TestCase):
             {"key1": 1, "key2": 2, "key3": 3, "key4": "4"},
         )
 
-        self.assertRaises(
-            KeyError,
-            STUB.keyValue_forObject_key_,
-            DO_VALUESFORKEYS,
-            o,
-            ["key1", "key2", "nokey", "key3"],
-        )
+        with self.assertRaisesRegex(KeyError, "nokey"):
+            STUB.keyValue_forObject_key_(
+                DO_VALUESFORKEYS,
+                o,
+                ["key1", "key2", "nokey", "key3"],
+            )
 
     def testTakeValueForKey(self):
         o = KeyValueClass2()
@@ -218,14 +253,13 @@ class PyKeyValueCoding(TestCase):
         STUB.setKeyValue_forObject_key_value_(DO_TAKEVALUE_FORKEY, o, "foo", "FOO")
         self.assertEqual(o.foo, "FOO")
 
-        self.assertRaises(
-            KeyError,
-            STUB.setKeyValue_forObject_key_value_,
-            DO_TAKEVALUE_FORKEY,
-            o,
-            "key9",
-            "IX",
-        )
+        with self.assertRaisesRegex(KeyError, "key9"):
+            STUB.setKeyValue_forObject_key_value_(
+                DO_TAKEVALUE_FORKEY,
+                o,
+                "key9",
+                "IX",
+            )
 
     def testTakeStoredValueForKey(self):
         o = KeyValueClass2()
@@ -247,7 +281,9 @@ class PyKeyValueCoding(TestCase):
         self.assertEqual(o.key5, "VVVVV")
 
         self.assertNotHasAttr(o, "key9")
-        STUB.setKeyValue_forObject_key_value_(DO_TAKESTOREDVALUE_FORKEY, o, "key9", "IX")
+        STUB.setKeyValue_forObject_key_value_(
+            DO_TAKESTOREDVALUE_FORKEY, o, "key9", "IX"
+        )
         self.assertHasAttr(o, "key9")
         self.assertEqual(o.key9, "IX")
 
@@ -255,25 +291,25 @@ class PyKeyValueCoding(TestCase):
         o = KeyValueClass3()
 
         self.assertEqual(o.foo, "foobar")
-        STUB.setKeyValue_forObject_key_value_(DO_TAKESTOREDVALUE_FORKEY, o, "foo", "FOO")
+        STUB.setKeyValue_forObject_key_value_(
+            DO_TAKESTOREDVALUE_FORKEY, o, "foo", "FOO"
+        )
         self.assertEqual(o.foo, "FOO")
 
-        self.assertRaises(
-            KeyError,
-            STUB.setKeyValue_forObject_key_value_,
-            DO_TAKESTOREDVALUE_FORKEY,
-            o,
-            "key9",
-            "IX",
-        )
-        self.assertRaises(
-            KeyError,
-            STUB.setKeyValue_forObject_key_value_,
-            DO_TAKESTOREDVALUE_FORKEY,
-            o,
-            "roprop",
-            "IX",
-        )
+        with self.assertRaisesRegex(KeyError, "Key key9 does not exist'"):
+            STUB.setKeyValue_forObject_key_value_(
+                DO_TAKESTOREDVALUE_FORKEY,
+                o,
+                "key9",
+                "IX",
+            )
+        with self.assertRaisesRegex(KeyError, "Key roprop does not exist'"):
+            STUB.setKeyValue_forObject_key_value_(
+                DO_TAKESTOREDVALUE_FORKEY,
+                o,
+                "roprop",
+                "IX",
+            )
 
     def testTakeValuesFromDictionary(self):
         o = KeyValueClass2()
@@ -305,22 +341,20 @@ class PyKeyValueCoding(TestCase):
         )
         self.assertEqual(o.foo, "FOO")
 
-        self.assertRaises(
-            KeyError,
-            STUB.setKeyValue_forObject_key_value_,
-            DO_TAKEVALUESFROMDICT,
-            o,
-            None,
-            {"key9": "IX"},
-        )
-        self.assertRaises(
-            KeyError,
-            STUB.setKeyValue_forObject_key_value_,
-            DO_TAKEVALUESFROMDICT,
-            o,
-            None,
-            {"roprop": "IX"},
-        )
+        with self.assertRaisesRegex(KeyError, "Key key9 does not exist"):
+            STUB.setKeyValue_forObject_key_value_(
+                DO_TAKEVALUESFROMDICT,
+                o,
+                None,
+                {"key9": "IX"},
+            )
+        with self.assertRaisesRegex(KeyError, "Key roprop does not exist"):
+            STUB.setKeyValue_forObject_key_value_(
+                DO_TAKEVALUESFROMDICT,
+                o,
+                None,
+                {"roprop": "IX"},
+            )
 
     def testTakeValueForKeyPath(self):
         o = KeyValueClass2()
@@ -354,12 +388,24 @@ class TestAccMethod(TestCase):
     def testStr(self):
         # Strings are automaticly converted to NSStrings, and those don't have
         # a capitalize key.
-        self.assertRaises(
-            KeyError, STUB.keyValue_forObject_key_, DO_VALUEFORKEY, "hello", "capitalize"
-        )
-        self.assertRaises(
-            KeyError, STUB.keyValue_forObject_key_, DO_VALUEFORKEY, "hello", "capitalize"
-        )
+        with self.assertRaisesRegex(
+            KeyError,
+            r"NSUnknownKeyException - \[.*\]: this class is not key value coding-compliant for the key capitalize.",
+        ):
+            STUB.keyValue_forObject_key_(
+                DO_VALUEFORKEY,
+                "hello",
+                "capitalize",
+            )
+        with self.assertRaisesRegex(
+            KeyError,
+            r"NSUnknownKeyException - \[.*\]: this class is not key value coding-compliant for the key capitalize.",
+        ):
+            STUB.keyValue_forObject_key_(
+                DO_VALUEFORKEY,
+                "hello",
+                "capitalize",
+            )
 
 
 class AbstractKVCodingTest:
@@ -462,7 +508,9 @@ class TestPythonSubOverObjC(AbstractKVCodingTest, TestCase):
         )
         self.assertEqual(
             IndirectString,
-            STUB.keyValue_forObject_key_(DO_VALUEFORKEY, self.base, "overIndirectString"),
+            STUB.keyValue_forObject_key_(
+                DO_VALUEFORKEY, self.base, "overIndirectString"
+            ),
         )
 
     def testOverValueKeyPath(self):
@@ -492,8 +540,6 @@ class TestPythonSubOverObjC(AbstractKVCodingTest, TestCase):
         )
 
 
-import sys, os
-
 if sys.platform == "darwin" and os.uname()[2] >= "7.0.0":
 
     # macOS 10.3 and later use 'setValue:forKey: u' instead of
@@ -548,14 +594,13 @@ if sys.platform == "darwin" and os.uname()[2] >= "7.0.0":
             STUB.setKeyValue_forObject_key_value_(DO_SETVALUE_FORKEY, o, "foo", "FOO")
             self.assertEqual(o.foo, "FOO")
 
-            self.assertRaises(
-                KeyError,
-                STUB.setKeyValue_forObject_key_value_,
-                DO_SETVALUE_FORKEY,
-                o,
-                "key9",
-                "IX",
-            )
+            with self.assertRaisesRegex(KeyError, "foo"):
+                STUB.setKeyValue_forObject_key_value_(
+                    DO_SETVALUE_FORKEY,
+                    o,
+                    "key9",
+                    "IX",
+                )
 
         def testSetValuesForKeysFromDictionary(self):
             o = KeyValueClass2()
@@ -587,22 +632,20 @@ if sys.platform == "darwin" and os.uname()[2] >= "7.0.0":
             )
             self.assertEqual(o.foo, "FOO")
 
-            self.assertRaises(
-                KeyError,
-                STUB.setKeyValue_forObject_key_value_,
-                DO_SETVALUESFORKEYSFROMDICT,
-                o,
-                None,
-                {"key9": "IX"},
-            )
-            self.assertRaises(
-                KeyError,
-                STUB.setKeyValue_forObject_key_value_,
-                DO_SETVALUESFORKEYSFROMDICT,
-                o,
-                None,
-                {"roprop": "IX"},
-            )
+            with self.assertRaisesRegex(KeyError, "foo"):
+                STUB.setKeyValue_forObject_key_value_(
+                    DO_SETVALUESFORKEYSFROMDICT,
+                    o,
+                    None,
+                    {"key9": "IX"},
+                )
+            with self.assertRaisesRegex(KeyError, "foo"):
+                STUB.setKeyValue_forObject_key_value_(
+                    DO_SETVALUESFORKEYSFROMDICT,
+                    o,
+                    None,
+                    {"roprop": "IX"},
+                )
 
         def testSetValueForKeyPath(self):
             o = KeyValueClass2()
@@ -645,10 +688,7 @@ if PyObjCTest_KeyValueObserver is not None:
     DEALLOCS = 0
 
     class PyObjCTestObserved1(NSObject):
-        if sys.version_info[0] == 3:
-            __slots__ = ("_kvo_bar", "_kvo_foo")
-        else:
-            __slots__ = (b"_kvo_bar", b"_kvo_foo")
+        __slots__ = ("_kvo_bar", "_kvo_foo")
 
         FOOBASE = "base"
 
@@ -761,7 +801,7 @@ if PyObjCTest_KeyValueObserver is not None:
             self.assertEqual(DEALLOCS, before + 1, "Leaking an observed object")
 
         def testObserving(self):
-            outer_pool = NSAutoreleasePool.alloc().init()
+            outer_pool = NSAutoreleasePool.alloc().init()  # noqa: F841
             observer = PyObjCTestObserver.alloc().init()
 
             o = PyObjCTestObserved1.alloc().init()
@@ -883,7 +923,3 @@ if PyObjCTest_KeyValueObserver is not None:
                 self.assertIsInstance(o, NSObject)
             finally:
                 o.removeObserver_forKeyPath_(observer, "observationInfo")
-
-
-if __name__ == "__main__":
-    main()
