@@ -3,38 +3,24 @@ Tests if NSSet conforms to the interface of the python type set()
 
 This is a port of the set tests from the Python stdlib for 3.2
 """
-from PyObjCTools.TestSupport import *
+import collections.abc
+import operator
+import test.test_set
+from test.test_set import PassThru, check_pass_thru
 
 import objc
-import operator
+from PyObjCTools.TestSupport import TestCase, skipUnless
 
 NSSet = objc.lookUpClass("NSSet")
 NSMutableSet = objc.lookUpClass("NSMutableSet")
 
-import test.test_set
-from test.test_set import PassThru, check_pass_thru
 
 test.test_set.empty_set = NSMutableSet()
-import operator
-
-
-import sys
-
-if sys.version_info[0] == 3:
-    unicode = str
-
-    def xrange(*args):
-        return list(range(*args))
-
-    import collections.abc as collections_abc
-
-else:
-    import collections as collections_abc
 
 
 class TestPyObjCSet(TestCase):
     def test_reverse_operator(self):
-        class MySet(collections_abc.Set):
+        class MySet(collections.abc.Set):
             def __init__(self, init=()):
                 self._value = list(init)
 
@@ -67,12 +53,16 @@ class TestPyObjCSet(TestCase):
         res = MySet([3, 4]) | s
         self.assertEqual(res, NSSet([1, 2, 3, 4]))
         self.assertIsInstance(res, NSSet)
-        self.assertRaises(TypeError, operator.or_, (3, 4), s)
+        with self.assertRaisesRegex(
+            TypeError, r"value\|NSSet where value is not a set"
+        ):
+            (3, 4) | s
 
         res = MySet([3, 4]) & s
         self.assertEqual(res, NSSet([3]))
         self.assertIsInstance(res, NSSet)
-        self.assertRaises(TypeError, operator.and_, (3, 4), s)
+        with self.assertRaisesRegex(TypeError, r"value&NSSet where value is not a set"):
+            (3, 4) & s
 
         res = MySet([3, 4]) - s
         self.assertEqual(res, NSSet([4]))
@@ -83,7 +73,7 @@ class TestPyObjCSet(TestCase):
         self.assertIsInstance(res, NSSet)
 
     def test_subset(self):
-        s = set([1, 2, 3])
+        s = {1, 2, 3}
         self.assertTrue(s.issubset([1, 2, 3, 4]))
         self.assertFalse(s.issubset([1, 2, 4, 5]))
 
@@ -92,7 +82,7 @@ class TestPyObjCSet(TestCase):
         self.assertFalse(s.issubset([1, 2, 4, 5]))
 
     def test_superset(self):
-        s = set([1, 2, 3])
+        s = {1, 2, 3}
         self.assertTrue(s.issuperset([1, 2]))
         self.assertFalse(s.issuperset([1, 5]))
 
@@ -102,13 +92,13 @@ class TestPyObjCSet(TestCase):
 
     def test_conversion(self):
         s = NSSet([1, 2, 3])
-        self.assertItemsEqual(list(s), [1, 2, 3])
+        self.assertCountEqual(list(s), [1, 2, 3])
 
         it = iter(s)
-        self.assertItemsEqual(list(it), [1, 2, 3])
+        self.assertCountEqual(list(it), [1, 2, 3])
 
         it = iter(s)
-        it.next()
+        next(it)
         v = list(it)
         self.assertEqual(len(v), 2)
         seen = set()
@@ -122,35 +112,35 @@ class TestSet(test.test_set.TestJointOps, TestCase):
     thetype = NSSet
     basetype = NSSet
 
-    @onlyIf(0, "test irrelevant for NSMutableSet")
+    @skipUnless(0, "test irrelevant for NSMutableSet")
     def test_cyclical_print(self):
         pass
 
-    @onlyIf(0, "test irrelevant for NSMutableSet")
+    @skipUnless(0, "test irrelevant for NSMutableSet")
     def test_cyclical_repr(self):
         pass
 
-    @onlyIf(0, "test irrelevant for NSMutableSet")
+    @skipUnless(0, "test irrelevant for NSMutableSet")
     def test_pickling(self):
         pass
 
-    @onlyIf(0, "test irrelevant for NSMutableSet")
+    @skipUnless(0, "test irrelevant for NSMutableSet")
     def test_do_not_rehash_dict_keys(self):
         pass
 
-    @onlyIf(0, "test irrelevant for NSMutableSet")
+    @skipUnless(0, "test irrelevant for NSMutableSet")
     def test_badcmp(self):
         pass
 
-    @onlyIf(0, "test irrelevant for NSMutableSet")
+    @skipUnless(0, "test irrelevant for NSMutableSet")
     def test_subclass_with_custom_hash(self):
         pass
 
-    @onlyIf(0, "test irrelevant for NSMutableSet")
+    @skipUnless(0, "test irrelevant for NSMutableSet")
     def test_iterator_pickling(self):
         pass
 
-    @onlyIf(0, "test irrelevant for NSMutableSet")
+    @skipUnless(0, "test irrelevant for NSMutableSet")
     def test_free_after_iterating(self):
         pass
 
@@ -168,18 +158,22 @@ class TestSet(test.test_set.TestJointOps, TestCase):
         self.assertEqual(self.s, self.thetype(self.word))
         # self.assertEqual(type(u), self.thetype)
         self.assertIsInstance(u, self.thetype)
-        self.assertRaises(PassThru, self.s.union, check_pass_thru())
-        self.assertRaises(TypeError, self.s.union, [[]])
-        for C in set, frozenset, dict.fromkeys, str, unicode, list, tuple:
+        with self.assertRaisesRegex(PassThru, "^$"):
+            self.s.union(check_pass_thru())
+        with self.assertRaisesRegex(TypeError, "unhashable type: 'list'"):
+            self.s.union([[]])
+        for C in set, frozenset, dict.fromkeys, str, list, tuple:
             self.assertEqual(self.thetype("abcba").union(C("cdc")), set("abcd"))
             self.assertEqual(self.thetype("abcba").union(C("efgfe")), set("abcefg"))
             self.assertEqual(self.thetype("abcba").union(C("ccb")), set("abc"))
             self.assertEqual(self.thetype("abcba").union(C("ef")), set("abcef"))
-            self.assertEqual(self.thetype("abcba").union(C("ef"), C("fg")), set("abcefg"))
+            self.assertEqual(
+                self.thetype("abcba").union(C("ef"), C("fg")), set("abcefg")
+            )
 
         # Issue #6573
         x = self.thetype()
-        self.assertEqual(x.union(set([1]), x, set([2])), self.thetype([1, 2]))
+        self.assertEqual(x.union({1}, x, {2}), self.thetype([1, 2]))
 
     def test_symmetric_difference(self):
         i = self.s.symmetric_difference(self.otherword)
@@ -188,9 +182,11 @@ class TestSet(test.test_set.TestJointOps, TestCase):
         self.assertEqual(self.s, self.thetype(self.word))
         # self.assertEqual(type(i), self.thetype)
         self.assertIsInstance(i, self.thetype)
-        self.assertRaises(PassThru, self.s.symmetric_difference, check_pass_thru())
-        self.assertRaises(TypeError, self.s.symmetric_difference, [[]])
-        for C in set, frozenset, dict.fromkeys, str, unicode, list, tuple:
+        with self.assertRaisesRegex(PassThru, "^$"):
+            self.s.symmetric_difference(check_pass_thru())
+        with self.assertRaisesRegex(TypeError, "unhashable type: 'list'"):
+            self.s.symmetric_difference([[]])
+        for C in set, frozenset, dict.fromkeys, str, list, tuple:
             self.assertEqual(
                 self.thetype("abcba").symmetric_difference(C("cdc")), set("abd")
             )
@@ -211,9 +207,11 @@ class TestSet(test.test_set.TestJointOps, TestCase):
         self.assertEqual(self.s, self.thetype(self.word))
         # self.assertEqual(type(i), self.thetype)
         self.assertIsInstance(i, self.thetype)
-        self.assertRaises(PassThru, self.s.difference, check_pass_thru())
-        self.assertRaises(TypeError, self.s.difference, [[]])
-        for C in set, frozenset, dict.fromkeys, str, unicode, list, tuple:
+        with self.assertRaisesRegex(PassThru, "^$"):
+            self.s.difference(check_pass_thru())
+        with self.assertRaisesRegex(TypeError, "unhashable type: 'list'"):
+            self.s.difference([[]])
+        for C in set, frozenset, dict.fromkeys, str, list, tuple:
             self.assertEqual(self.thetype("abcba").difference(C("cdc")), set("ab"))
             self.assertEqual(self.thetype("abcba").difference(C("efgfe")), set("abc"))
             self.assertEqual(self.thetype("abcba").difference(C("ccb")), set("a"))
@@ -228,8 +226,9 @@ class TestSet(test.test_set.TestJointOps, TestCase):
         self.assertEqual(self.s, self.thetype(self.word))
         # self.assertEqual(type(i), self.thetype)
         self.assertIsInstance(i, self.thetype)
-        self.assertRaises(PassThru, self.s.intersection, check_pass_thru())
-        for C in set, frozenset, dict.fromkeys, str, unicode, list, tuple:
+        with self.assertRaisesRegex(PassThru, "^$"):
+            self.s.intersection(check_pass_thru())
+        for C in set, frozenset, dict.fromkeys, str, list, tuple:
             self.assertEqual(self.thetype("abcba").intersection(C("cdc")), set("cc"))
             self.assertEqual(self.thetype("abcba").intersection(C("efgfe")), set(""))
             self.assertEqual(self.thetype("abcba").intersection(C("ccb")), set("bc"))
@@ -265,17 +264,12 @@ class TestSet(test.test_set.TestJointOps, TestCase):
         self.assertEqual(id(self.s), id(dup))
 
     def test_as_list(self):
-        l = list(self.s)
-        self.assertIsInstance(l, list)
-        self.assertEqual(len(l), len(self.s))
-        for item in l:
+        lst = list(self.s)
+        self.assertIsInstance(lst, list)
+        self.assertEqual(len(lst), len(self.s))
+        for item in lst:
             self.assertIn(item, self.s)
 
-    @onlyPython2
-    def test_cmp_function(self):
-        self.assertRaises(TypeError, cmp, self.s, "hello")
-        self.assertRaises(TypeError, self.s.__cmp__, self.s)
-
 
 class TestMutableSet(TestSet, test.test_set.TestSet):
     thetype = NSMutableSet
@@ -290,23 +284,23 @@ class TestMutableSet(TestSet, test.test_set.TestSet):
         self.assertIsInstance(dup, self.basetype)
 
     # Tests from 'TestSet'
-    @onlyIf(0, "test irrelevant for NSMutableSet")
+    @skipUnless(0, "test irrelevant for NSMutableSet")
     def test_init(self):
         pass
 
-    @onlyIf(0, "test irrelevant for NSMutableSet")
+    @skipUnless(0, "test irrelevant for NSMutableSet")
     def test_hash(self):
         pass
 
-    @onlyIf(0, "test irrelevant for NSMutableSet")
+    @skipUnless(0, "test irrelevant for NSMutableSet")
     def test_weakref(self):
         pass
 
-    @onlyIf(0, "test irrelevant for NSMutableSet")
+    @skipUnless(0, "test irrelevant for NSMutableSet")
     def test_iterator_pickling(self):
         pass
 
-    @onlyIf(0, "test irrelevant for NSMutableSet")
+    @skipUnless(0, "test irrelevant for NSMutableSet")
     def test_free_after_iterating(self):
         pass
 
@@ -438,8 +432,7 @@ class TestOnlySetsTuple(test.test_set.TestOnlySetsTuple):
 class TestOnlySetsString(test.test_set.TestOnlySetsString):
     def setUp(self):
         def gen():
-            for i in range(0, 10, 2):
-                yield i
+            yield from range(0, 10, 2)
 
         self.set = NSMutableSet((1, 2, 3))
         self.other = gen()
@@ -465,7 +458,7 @@ class TestVariousIteratorArgs(test.test_set.TestVariousIteratorArgs):
             "",
             range(1000),
             ("do", 1.2),
-            xrange(2000, 2200, 5),
+            range(2000, 2200, 5),
             "december",
         ):
             for methname in (
@@ -474,33 +467,37 @@ class TestVariousIteratorArgs(test.test_set.TestVariousIteratorArgs):
                 "difference_update",
                 "symmetric_difference_update",
             ):
-                for g in (
-                    test.test_set.G,
-                    test.test_set.I,
-                    test.test_set.Ig,
-                    test.test_set.S,
-                    test.test_set.L,
-                    test.test_set.R,
-                ):
-                    # s = set('january')
-                    s = NSMutableSet("january")
-                    # t = s.copy()
-                    t = s.mutableCopy()
-                    getattr(s, methname)(list(g(data)))
-                    getattr(t, methname)(g(data))
-                    self.assertEqual(sorted(s, key=repr), sorted(t, key=repr))
+                with self.subTest(methname):
+                    for g in (
+                        test.test_set.G,
+                        test.test_set.I,
+                        test.test_set.Ig,
+                        test.test_set.S,
+                        test.test_set.L,
+                        test.test_set.R,
+                    ):
+                        # s = set('january')
+                        s = NSMutableSet("january")
+                        # t = s.copy()
+                        t = s.mutableCopy()
+                        getattr(s, methname)(list(g(data)))
+                        getattr(t, methname)(g(data))
+                        self.assertEqual(sorted(s, key=repr), sorted(t, key=repr))
 
-                self.assertRaises(
-                    TypeError, getattr(set("january"), methname), test.test_set.X(data)
-                )
-                self.assertRaises(
-                    TypeError, getattr(set("january"), methname), test.test_set.N(data)
-                )
-                self.assertRaises(
-                    ZeroDivisionError,
-                    getattr(set("january"), methname),
-                    test.test_set.E(data),
-                )
+                    with self.assertRaisesRegex(
+                        TypeError, "'X' object is not iterable"
+                    ):
+                        getattr(set("january"), methname)(test.test_set.X(data))
+
+                    with self.assertRaisesRegex(
+                        TypeError, r"iter\(\) returned non-iterator of type 'N'"
+                    ):
+                        getattr(set("january"), methname)(test.test_set.N(data))
+
+                    with self.assertRaisesRegex(
+                        ZeroDivisionError, "integer division or modulo by zero"
+                    ):
+                        getattr(set("january"), methname)(test.test_set.E(data))
 
 
 class TestGraphs(test.test_set.TestGraphs):
@@ -509,7 +506,3 @@ class TestGraphs(test.test_set.TestGraphs):
 
     def tearDown(self):
         del test.test_set.set
-
-
-if __name__ == "__main__":
-    main()
